PALM-meteo: palmmeteo.utils.SliceExtender Class Reference

PALM-meteo

Public Member Functions | Public Attributes | List of all members
palmmeteo.utils.SliceExtender Class Reference

## Public Member Functions
def | __init__ (self, slice_obj, *slices)
def | __getitem__ (self, key)

## Public Attributes
| slice_obj
| slices

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo.utils.SliceExtender.__init__ | ( |  | self,
|  |  | slice_obj,
|  | * | slices
| ) |  |

## Member Function Documentation

## ◆ __getitem__()

def palmmeteo.utils.SliceExtender.__getitem__ | ( |  | self,
|  |  | key
| ) |  |

## Member Data Documentation

## ◆ slice_obj

palmmeteo.utils.SliceExtender.slice_obj

## ◆ slices

palmmeteo.utils.SliceExtender.slices

The documentation for this class was generated from the following file:

- palmmeteo/utils.py